# art-daq
Librería dedicada al uso de la tarjeta USB-6001. Se pretende que sea una librería de uso sencillo y accesible.  
Library dedicated to the use of the USB-6001 daq. It is intended to be a simple and accessible library.  

La instalación de este paquete se puede realizar a través del comando pip install art-daq. Si se necesita actualizarla, se usará el comando pip install --upgrade art-daq. 
Para poder usar este paquete se usará la estructura from art_daq import prueba. 
